==> qtjambi-script-debuginfo-macos-5.15.18.jar: sources/QtJambiScript/QScriptString_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScript/qscriptstring.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScriptString(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScriptString")
    QScriptString *_ptr = reinterpret_cast<QScriptString *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScriptString()
void __qt_construct_QScriptString_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptString()")
    Q_UNUSED(__java_arguments)
    QScriptString *__qt_this = new(__qtjambi_ptr) QScriptString();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QScriptString(QScriptString)
void __qt_construct_QScriptString_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptString(QScriptString)")
    jobject other0 = __java_arguments[0].l;
    const QScriptString& __qt_other0 = qtjambi_cast<const QScriptString& >(__jni_env, other0);
    QScriptString *__qt_this = new(__qtjambi_ptr) QScriptString(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QScriptString
void __qt_destruct_QScriptString(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScriptString")
    reinterpret_cast<QScriptString*>(ptr)->~QScriptString();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScriptString::QScriptString()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_initialize_1native__Lio_qt_script_QScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptString::QScriptString()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptString_0, sizeof(QScriptString), typeid(QScriptString), false, &deleter_QScriptString, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptString::QScriptString(QScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_initialize_1native__Lio_qt_script_QScriptString_2Lio_qt_script_QScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptString::QScriptString(QScriptString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptString_1, sizeof(QScriptString), typeid(QScriptString), false, &deleter_QScriptString, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptString::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptString::operator=(QScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_assign_1native_1cref_1QScriptString__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::operator=(QScriptString)", __qt_this)
        const QScriptString& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QScriptString>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptString::operator==(QScriptString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_equals_1native_1cref_1QScriptString_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::operator==(QScriptString)const", __qt_this)
        const QScriptString& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QScriptString>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptString::toArrayIndex(bool*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_toArrayIndex_1native_1bool_1ptr_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::toArrayIndex(bool*)const", __qt_this)
        bool ok(false);
        bool* __qt_ok0 = &ok;
        quint32 __qt_return_value = __qt_this->toArrayIndex(__qt_ok0);
        __java_return_value = ok ? QtJambiAPI::toJavaIntegerObject(__jni_env, __qt_return_value) : nullptr;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptString::toString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_toString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::toString()const", __qt_this)
        QString __qt_return_value = __qt_this->toString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScriptString(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QScriptString>("QScriptString", "io/qt/script/QScriptString");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScriptString, {
        ConstructorInfo(&__qt_construct_QScriptString_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QScriptString_1, "Lio/qt/script/QScriptString;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScriptString);
    registerMetaType<QScriptString>("QScriptString");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-script-debuginfo-macos-5.15.20.jar: sources/QtJambiScript/QScriptString_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtScript/qscriptstring.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QScriptString(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScriptString")
    QScriptString *_ptr = reinterpret_cast<QScriptString *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QScriptString()
void __qt_construct_QScriptString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptString()")
    Q_UNUSED(__java_arguments)
    QScriptString *__qt_this = new(__qtjambi_ptr) QScriptString();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QScriptString::QScriptString()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_initialize_1native__Lio_qt_script_QScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptString::QScriptString()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptString, sizeof(QScriptString), typeid(QScriptString), false, &deleter_QScriptString, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QScriptString(QScriptString)
void __qt_construct_QScriptString_cref_QScriptString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScriptString(QScriptString)")
    jobject other0 = __java_arguments[0].l;
    const QScriptString& __qt_other0 = qtjambi_cast<const QScriptString& >(__jni_env, other0);
    QScriptString *__qt_this = new(__qtjambi_ptr) QScriptString(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScriptString::QScriptString(QScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_initialize_1native__Lio_qt_script_QScriptString_2Lio_qt_script_QScriptString_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScriptString::QScriptString(QScriptString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScriptString_cref_QScriptString, sizeof(QScriptString), typeid(QScriptString), false, &deleter_QScriptString, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScriptString
void __qt_destruct_QScriptString(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScriptString")
    reinterpret_cast<QScriptString*>(ptr)->~QScriptString();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScriptString::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptString::operator=(QScriptString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_assign_1native_1cref_1QScriptString__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::operator=(QScriptString)", __qt_this)
        const QScriptString& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QScriptString>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScriptString::operator==(QScriptString)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_equals_1native_1cref_1QScriptString_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::operator==(QScriptString)const", __qt_this)
        const QScriptString& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QScriptString>(other0);
        __java_return_value = (*__qt_this) == __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptString::toArrayIndex(bool*)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_toArrayIndex_1native_1bool_1ptr_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::toArrayIndex(bool*)const", __qt_this)
        bool ok(false);
        bool* __qt_ok0 = &ok;
        quint32 __qt_return_value = __qt_this->toArrayIndex(__qt_ok0);
        __java_return_value = ok ? QtJambiAPI::toJavaIntegerObject(__jni_env, __qt_return_value) : nullptr;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScriptString::toString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_toString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScriptString::toString()const", __qt_this)
        QString __qt_return_value = __qt_this->toString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_script_QScriptString_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScriptString *__qt_this = QtJambiAPI::objectFromNativeId<QScriptString>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScriptString(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QScriptString>("QScriptString", "io/qt/script/QScriptString");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScriptString, {
        ConstructorInfo(&__qt_construct_QScriptString, nullptr)
       ,ConstructorInfo(&__qt_construct_QScriptString_cref_QScriptString, "Lio/qt/script/QScriptString;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScriptString);
    registerMetaType<QScriptString>("QScriptString");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
